# cli_isis_data Templates

cli_isis_data template designed for use with N2G library to produce network diagrams based on ISIS 
link state database of Cisco IOS-XR devices. 

Caveats:

 - need `ttp>=0.8.0` for extend to work
 
Results structure example:

```
TBD
```